summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/player.cc
diff options
context:
space:
mode:
authordolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-09-25 04:55:41 +0000
committerdolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-09-25 04:55:41 +0000
commit915c2ffc0aa07bb33e09b11b5e2275c034fb5d96 (patch)
tree97c79cd1a1a1d929799d656e2463edce432b9517 /crawl-ref/source/player.cc
parent87df3f8adf2ce93247abaece1b11a10bedd9c44c (diff)
downloadcrawl-ref-915c2ffc0aa07bb33e09b11b5e2275c034fb5d96.tar.gz
crawl-ref-915c2ffc0aa07bb33e09b11b5e2275c034fb5d96.zip
Adapt Zin's old Divine Robustness into Elyvilon's Divine Vigour,
replacing the old Incredible Healing. git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@6980 c06c8d41-db1a-0410-9941-cceddc491573
Diffstat (limited to 'crawl-ref/source/player.cc')
-rw-r--r--crawl-ref/source/player.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/crawl-ref/source/player.cc b/crawl-ref/source/player.cc
index 15488f5747..664fc387ff 100644
--- a/crawl-ref/source/player.cc
+++ b/crawl-ref/source/player.cc
@@ -3921,7 +3921,7 @@ void display_char_status()
if (you.duration[DUR_MIGHT])
mpr( "You are mighty." );
- if (you.duration[DUR_DIVINE_ROBUSTNESS])
+ if (you.duration[DUR_DIVINE_VIGOUR])
mpr( "You are divinely robust." );
if (you.duration[DUR_DIVINE_STAMINA])
@@ -4912,10 +4912,10 @@ int get_real_hp(bool trans, bool rotted)
if (rotted)
hitp += player_rotted();
- // Frail and robust mutations, and divine robustness.
- hitp *= (10 + player_mutation_level(MUT_ROBUST)
- + you.attribute[ATTR_DIVINE_ROBUSTNESS]
- - player_mutation_level(MUT_FRAIL));
+ // Frail and robust mutations, and divine vigour.
+ hitp *= 10 + player_mutation_level(MUT_ROBUST)
+ + you.attribute[ATTR_DIVINE_VIGOUR]
+ - player_mutation_level(MUT_FRAIL);
hitp /= 10;
return (hitp);